@@ -1,9 +1,10 @@
 # Supress R CMD check note 'no visible binding for global variable ...' ########
 # Source: http://stackoverflow.com/a/12429344/3365410
 if (getRversion() >= "2.15.1") {
-  utils::globalVariables(names = c("covars.type", "sm", "n_pts", "n_cov", 
-                                   "n_candi", "wp", "conf0", "pre.distri",
-                                   "pop.prop"))
+  utils::globalVariables(
+    names = c("covars.type", "sm", "n_pts", "n_cov", "n_candi", "wp", "conf0", 
+              "pre.distri", "pop.prop", "id_fac", "id_num", "probs", "breaks",
+              "pcm", "pop_prop", "covars_type"))
 }
 
 # Import functions from default packages other than `base` #####################
@@ -11,3 +12,4 @@ if (getRversion() >= "2.15.1") {
 #' @importFrom stats cor quantile runif terms
 #' @importFrom graphics axis hist legend lines mtext par plot points text
 #' @importFrom utils setTxtProgressBar txtProgressBar head tail
+#' @importFrom grDevices dev.set dev.prev dev.next dev.new
